@@ -1,7 +1,7 @@
 /* CatalystX::CRUD::YUI custom JavaScript 
 
 # sync with .pm files
-my $VERSION = '0.027';   
+my $VERSION = '0.028';   
 
 */
 YAHOO.namespace('crud');
@@ -624,7 +624,7 @@ YAHOO.crud.livegrid_filter = Ext.extend(Ext.form.TwinTriggerField, {
         
         // explicitly set the wrapper width since multiple triggerfields
         // on same page get set to 0width. (ext js bug!?)
-        this.wrap.setWidth(180);
+        this.wrap.setWidth(this.width);
     
     },
 
@@ -633,7 +633,7 @@ YAHOO.crud.livegrid_filter = Ext.extend(Ext.form.TwinTriggerField, {
     trigger1Class:'x-form-clear-trigger',
     trigger2Class:'x-form-search-trigger',
     hideTrigger1:true,
-    width:180,
+    width:380,
     hasSearch : false,
     paramName : 'cxc-query',
 
@@ -766,7 +766,7 @@ YAHOO.crud.new_livegrid = function(index) {
                 ' ',
                 new YAHOO.crud.livegrid_filter({
                     'store': this.store,  // TODO is this correct?
-                    'width': 200,
+                    'width': 400,
                     'text_fields': opts.text_columns
                 })
             ]
